@@ -164,6 +164,32 @@ GpgME::Error GpgME::Data::setEncoding(Encoding enc)
     return Error(gpgme_data_set_encoding(d->data, ge));
 }
 
+GpgME::Data::Type GpgME::Data::type() const
+{
+    if (isNull()) {
+        return Invalid;
+    }
+#ifdef HAVE_GPGME_DATA_IDENTIFY
+    switch (gpgme_data_identify(d->data, 0)) {
+    case GPGME_DATA_TYPE_INVALID:       return Invalid;
+    case GPGME_DATA_TYPE_UNKNOWN:       return Unknown;
+    case GPGME_DATA_TYPE_PGP_SIGNED:    return PGPSigned;
+    case GPGME_DATA_TYPE_PGP_OTHER:     return PGPOther;
+    case GPGME_DATA_TYPE_PGP_KEY:       return PGPKey;
+    case GPGME_DATA_TYPE_CMS_SIGNED:    return CMSSigned;
+    case GPGME_DATA_TYPE_CMS_ENCRYPTED: return CMSEncrypted;
+    case GPGME_DATA_TYPE_CMS_OTHER:     return CMSOther;
+    case GPGME_DATA_TYPE_X509_CERT:     return X509Cert;
+    case GPGME_DATA_TYPE_PKCS12:        return PKCS12;
+# ifdef HAVE_GPGME_DATA_IDENTIFY_GOOD
+    case GPGME_DATA_TYPE_PGP_ENCRYPTED: return PGPEncrypted;
+    case GPGME_DATA_TYPE_PGP_SIGNATURE: return PGPSignature;
+# endif
+    }
+#endif
+    return Unknown;
+}
+
 char *GpgME::Data::fileName() const
 {
 #ifdef HAVE_GPGME_DATA_SET_FILE_NAME
